==> events-0.8.1-sources.jar: software/amazon/awscdk/services/events/EventRule.java <==
package software.amazon.awscdk.services.events;
/**
 * Defines a CloudWatch Event Rule in this stack.
 */
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.events.$Module.class, fqn = "@aws-cdk/aws-events.EventRule")
public class EventRule extends software.amazon.awscdk.services.events.EventRuleRef {
    protected EventRule(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    public EventRule(final software.amazon.awscdk.Construct parent, final java.lang.String name, @javax.annotation.Nullable final software.amazon.awscdk.services.events.EventRuleProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(parent, "parent is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(name, "name is required"))), java.util.stream.Stream.of(props)).toArray());
    }
    public EventRule(final software.amazon.awscdk.Construct parent, final java.lang.String name) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(parent, "parent is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(name, "name is required"))).toArray());
    }
    /**
     * Adds a target to the rule. The abstract class RuleTarget can be extended to define new
     * targets.
     * 
     * No-op if target is undefined.
     */
    public void addTarget(@javax.annotation.Nullable final software.amazon.awscdk.services.events.IEventRuleTarget target, @javax.annotation.Nullable final software.amazon.awscdk.services.events.TargetInputTemplate inputOptions) {
        this.jsiiCall("addTarget", Void.class, java.util.stream.Stream.concat(java.util.stream.Stream.of(target), java.util.stream.Stream.of(inputOptions)).toArray());
    }
    /**
     * Adds a target to the rule. The abstract class RuleTarget can be extended to define new
     * targets.
     * 
     * No-op if target is undefined.
     */
    public void addTarget(@javax.annotation.Nullable final software.amazon.awscdk.services.events.IEventRuleTarget target) {
        this.jsiiCall("addTarget", Void.class, java.util.stream.Stream.of(target).toArray());
    }
    /**
     * Adds a target to the rule. The abstract class RuleTarget can be extended to define new
     * targets.
     * 
     * No-op if target is undefined.
     */
    public void addTarget() {
        this.jsiiCall("addTarget", Void.class);
    }
    /**
     * Adds an event pattern filter to this rule. If a pattern was already specified,
     * these values are merged into the existing pattern.
     * 
     * For example, if the rule already contains the pattern:
     * 
     *       {
     *           "resources": [ "r1" ],
     *           "detail": {
     *               "hello": [ 1 ]
     *           }
     *       }
     * 
     * And `addEventPattern` is called with the pattern:
     * 
     *       {
     *           "resources": [ "r2" ],
     *           "detail": {
     *               "foo": [ "bar" ]
     *           }
     *       }
     * 
     * The resulting event pattern will be:
     * 
     *       {
     *           "resources": [ "r1", "r2" ],
     *           "detail": {
     *               "hello": [ 1 ],
     *               "foo": [ "bar" ]
     *           }
     *       }
     */
    public void addEventPattern(@javax.annotation.Nullable final software.amazon.awscdk.services.events.EventPattern eventPattern) {
        this.jsiiCall("addEventPattern", Void.class, java.util.stream.Stream.of(eventPattern).toArray());
    }
    /**
     * Adds an event pattern filter to this rule. If a pattern was already specified,
     * these values are merged into the existing pattern.
     * 
     * For example, if the rule already contains the pattern:
     * 
     *       {
     *           "resources": [ "r1" ],
     *           "detail": {
     *               "hello": [ 1 ]
     *           }
     *       }
     * 
     * And `addEventPattern` is called with the pattern:
     * 
     *       {
     *           "resources": [ "r2" ],
     *           "detail": {
     *               "foo": [ "bar" ]
     *           }
     *       }
     * 
     * The resulting event pattern will be:
     * 
     *       {
     *           "resources": [ "r1", "r2" ],
     *           "detail": {
     *               "hello": [ 1 ],
     *               "foo": [ "bar" ]
     *           }
     *       }
     */
    public void addEventPattern() {
        this.jsiiCall("addEventPattern", Void.class);
    }
    /**
     * This method can be implemented by derived constructs in order to perform
     * validation logic. It is called on all constructs before synthesis.
     */
    public java.util.List<java.lang.String> validate() {
        return this.jsiiCall("validate", java.util.List.class);
    }
    /**
     * The value of the event rule Amazon Resource Name (ARN), such as
     * arn:aws:events:us-east-2:123456789012:rule/example.
     */
    public software.amazon.awscdk.services.events.RuleArn getRuleArn() {
        return this.jsiiGet("ruleArn", software.amazon.awscdk.services.events.RuleArn.class);
    }
}

==> events-0.9.0-sources.jar: software/amazon/awscdk/services/events/EventRule.java <==
package software.amazon.awscdk.services.events;

/**
 * Defines a CloudWatch Event Rule in this stack.
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.4 (build e80a889)", date = "2018-09-11T09:57:01.408Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.events.$Module.class, fqn = "@aws-cdk/aws-events.EventRule")
public class EventRule extends software.amazon.awscdk.services.events.EventRuleRef {
    protected EventRule(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    public EventRule(final software.amazon.awscdk.Construct parent, final java.lang.String name, final software.amazon.awscdk.services.events.EventRuleProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(parent, "parent is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(name, "name is required"))), java.util.stream.Stream.of(java.util.Objects.requireNonNull(props, "props is required"))).toArray());
    }

    /**
     * Adds an event pattern filter to this rule. If a pattern was already specified,
     * these values are merged into the existing pattern.
     * 
     * For example, if the rule already contains the pattern:
     * 
     *       {
     *           "resources": [ "r1" ],
     *           "detail": {
     *               "hello": [ 1 ]
     *           }
     *       }
     * 
     * And `addEventPattern` is called with the pattern:
     * 
     *       {
     *           "resources": [ "r2" ],
     *           "detail": {
     *               "foo": [ "bar" ]
     *           }
     *       }
     * 
     * The resulting event pattern will be:
     * 
     *       {
     *           "resources": [ "r1", "r2" ],
     *           "detail": {
     *               "hello": [ 1 ],
     *               "foo": [ "bar" ]
     *           }
     *       }
     */
    public void addEventPattern(@javax.annotation.Nullable final software.amazon.awscdk.services.events.EventPattern eventPattern) {
        this.jsiiCall("addEventPattern", Void.class, java.util.stream.Stream.of(eventPattern).toArray());
    }

    /**
     * Adds an event pattern filter to this rule. If a pattern was already specified,
     * these values are merged into the existing pattern.
     * 
     * For example, if the rule already contains the pattern:
     * 
     *       {
     *           "resources": [ "r1" ],
     *           "detail": {
     *               "hello": [ 1 ]
     *           }
     *       }
     * 
     * And `addEventPattern` is called with the pattern:
     * 
     *       {
     *           "resources": [ "r2" ],
     *           "detail": {
     *               "foo": [ "bar" ]
     *           }
     *       }
     * 
     * The resulting event pattern will be:
     * 
     *       {
     *           "resources": [ "r1", "r2" ],
     *           "detail": {
     *               "hello": [ 1 ],
     *               "foo": [ "bar" ]
     *           }
     *       }
     */
    public void addEventPattern() {
        this.jsiiCall("addEventPattern", Void.class);
    }

    /**
     * Adds a target to the rule. The abstract class RuleTarget can be extended to define new
     * targets.
     * 
     * No-op if target is undefined.
     */
    public void addTarget(@javax.annotation.Nullable final software.amazon.awscdk.services.events.IEventRuleTarget target, @javax.annotation.Nullable final software.amazon.awscdk.services.events.TargetInputTemplate inputOptions) {
        this.jsiiCall("addTarget", Void.class, java.util.stream.Stream.concat(java.util.stream.Stream.of(target), java.util.stream.Stream.of(inputOptions)).toArray());
    }

    /**
     * Adds a target to the rule. The abstract class RuleTarget can be extended to define new
     * targets.
     * 
     * No-op if target is undefined.
     */
    public void addTarget(@javax.annotation.Nullable final software.amazon.awscdk.services.events.IEventRuleTarget target) {
        this.jsiiCall("addTarget", Void.class, java.util.stream.Stream.of(target).toArray());
    }

    /**
     * Adds a target to the rule. The abstract class RuleTarget can be extended to define new
     * targets.
     * 
     * No-op if target is undefined.
     */
    public void addTarget() {
        this.jsiiCall("addTarget", Void.class);
    }

    /**
     * This method can be implemented by derived constructs in order to perform
     * validation logic. It is called on all constructs before synthesis.
     */
    @Override
    public java.util.List<java.lang.String> validate() {
        return this.jsiiCall("validate", java.util.List.class);
    }

    /**
     * The value of the event rule Amazon Resource Name (ARN), such as
     * arn:aws:events:us-east-2:123456789012:rule/example.
     */
    @Override
    public software.amazon.awscdk.services.events.RuleArn getRuleArn() {
        return this.jsiiGet("ruleArn", software.amazon.awscdk.services.events.RuleArn.class);
    }
}
